@@ -29,7 +29,7 @@
 
 (defvar mm-content-transfer-encoding-defaults
   '(("text/.*" quoted-printable)
-    ("message/rfc822" quoted-printable)
+    ("message/rfc822" 8bit)
     ("application/emacs-lisp" 8bit)
     ("application/x-patch" 8bit)
     (".*" base64))
